@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -- |
 -- Module    : Numeric.SpecFunctions
 -- Copyright : (c) 2009, 2011, 2012 Bryan O'Sullivan
@@ -28,6 +29,7 @@ module Numeric.SpecFunctions (
     -- * Sinc
   , sinc
     -- * Logarithm
+    -- $log1p
   , log1p
   , log1pmx
   , log2
@@ -45,6 +47,17 @@ module Numeric.SpecFunctions (
   ) where
 
 import Numeric.SpecFunctions.Internal
+#if MIN_VERSION_base(4,9,0)
+import GHC.Float (log1p, expm1)
+#endif
+
+
+-- $log1p
+--
+-- Base starting from @4.9.0@ (GHC 8.0) provides 'log1p' and 'expm1'
+-- as method of class 'Floating'. In this case we simply reexport
+-- these function. Otherwise we provide our own with more restrictive
+-- signature @Double → Double@.
 
 -- $references
 --
