@@ -1,4 +1,4 @@
-{-# LANGUAGE BangPatterns, ScopedTypeVariables, ForeignFunctionInterface #-}
+{-# LANGUAGE CPP, BangPatterns, ScopedTypeVariables, ForeignFunctionInterface #-}
 -- |
 -- Module    : Numeric.SpecFunctions.Internal
 -- Copyright : (c) 2009, 2011, 2012 Bryan O'Sullivan
@@ -11,22 +11,25 @@
 -- Internal module with implementation of special functions.
 module Numeric.SpecFunctions.Internal where
 
+#if !MIN_VERSION_base(4,9,0)
 import Control.Applicative
+#endif
 import Data.Bits       ((.&.), (.|.), shiftR)
 import Data.Int        (Int64)
 import Data.Word       (Word)
 import qualified Data.Vector.Unboxed as U
 import           Data.Vector.Unboxed   ((!))
+import Text.Printf
+#if MIN_VERSION_base(4,9,0)
+import GHC.Float (log1p,expm1)
+#endif
 
 import Numeric.Polynomial.Chebyshev    (chebyshevBroucke)
 import Numeric.Polynomial              (evaluatePolynomialL,evaluateEvenPolynomialL,evaluateOddPolynomialL)
 import Numeric.RootFinding             (Root(..), newtonRaphson)
-import Numeric.Series                  (sumPowerSeries,enumSequenceFrom,scanSequence,evalContFractionB)
-import Numeric.MathFunctions.Constants ( m_epsilon, m_NaN, m_neg_inf, m_pos_inf
-                                       , m_sqrt_2_pi, m_ln_sqrt_2_pi, m_eulerMascheroni
-                                       , m_min_log, m_tiny
-                                       )
-import Text.Printf
+import Numeric.Series
+import Numeric.MathFunctions.Constants
+
 
 
 ----------------------------------------------------------------
@@ -718,6 +721,8 @@ sinc x
 -- Logarithm
 ----------------------------------------------------------------
 
+-- GHC.Float provides log1p and expm1 since 4.9.0
+#if !MIN_VERSION_base(4,9,0)
 -- | Compute the natural logarithm of 1 + @x@.  This is accurate even
 -- for values of @x@ near zero, where use of @log(1+x)@ would lose
 -- precision.
@@ -758,6 +763,23 @@ log1p x
               -0.10324619158271569595141333961932e-15
              ]
 
+-- | Compute @exp x - 1@ without loss of accuracy for x near zero.
+expm1 :: Double -> Double
+#ifdef USE_SYSTEM_EXPM1
+expm1 = c_expm1
+
+foreign import ccall "expm1" c_expm1 :: Double -> Double
+#else
+-- NOTE: this is simplest implementation and not terribly efficient.
+expm1 x
+  | x < (-37.42994775023705) = -1
+  | x > m_max_log            = m_pos_inf
+  | abs x > 0.5              = exp x - 1
+  | otherwise                = sumSeries $ liftA2 (*) (scanSequence (*) x (pure x))
+                                                      (1 / scanSequence (*) 1 (enumSequenceFrom 2))
+#endif
+#endif
+
 -- | Compute log(1+x)-x:
 log1pmx :: Double -> Double
 log1pmx x
@@ -769,14 +791,6 @@ log1pmx x
   where
    ax = abs x
 
--- | Compute @exp x - 1@ without loss of accuracy for x near zero.
-expm1 :: Double -> Double
-expm1 = c_expm1
-
-foreign import ccall "expm1" c_expm1 :: Double -> Double
-
-
-
 -- | /O(log n)/ Compute the logarithm in base 2 of the given value.
 log2 :: Int -> Int
 log2 v0
